@@ -3,14 +3,11 @@ import hashlib
 import shutil
 import subprocess
 import urlparse
-import collections
 import re
 import urllib
 
 import blah
-import catchy
-
-from whack.filelock import FileLock
+import locket
 
 
 class Download(object):
@@ -26,7 +23,32 @@ class Download(object):
         
     def __repr__(self):
         return "Download({0!r}, {1!r})".format(self.url, self.filename)
+
         
+def fetch_downloads(downloads_file_path, build_env, target_dir):
+    downloads_file = _read_downloads_file(downloads_file_path, build_env)
+    for download_line in downloads_file:
+        download(
+            download_line.url,
+            os.path.join(target_dir, download_line.filename)
+        )
+
+
+def _read_downloads_file(path, build_env):
+    if os.path.exists(path):
+        first_line = open(path).readline()
+        if first_line.startswith("#!"):
+            downloads_string = subprocess.check_output(
+                [path],
+                env=build_env
+            )
+        else:
+            downloads_string = open(path).read()
+            
+        return read_downloads_string(downloads_string)
+    else:
+        return []
+
 
 def read_downloads_string(downloads_string):
     return [
@@ -53,7 +75,7 @@ def _download_to_cache(url):
     url_hash = hashlib.sha1(url).hexdigest()
     cache_file = os.path.join(cache_dir, url_hash)
     subprocess.check_call(["mkdir", "-p", cache_dir])
-    with FileLock(cache_file):
+    with locket.lock_file("{0}.lock".format(cache_file)):
         if not os.path.exists(cache_file):
             urllib.urlretrieve(url, cache_file)
     return cache_file
