@@ -1,25 +1,20 @@
 import os
 import subprocess
 import shutil
-import json
-import contextlib
 
 from . import downloads
-from .hashes import Hasher
 from .tempdir import create_temporary_dir
+from .naming import name_package
 from .common import WHACK_ROOT
+from .files import mkdir_p
 
 
 class BuildingPackageProvider(object):
-    @contextlib.contextmanager
-    def provide_package(self, package_src, params):
+    def provide_package(self, package_src, params, package_dir):
         with create_temporary_dir() as temp_dir:
             build_dir = os.path.join(temp_dir, "build")
-            package_dir = os.path.join(temp_dir, "package")
             
             self._build(package_src, build_dir, package_dir, params)
-                
-            yield package_dir
     
     def _build(self, package_src, build_dir, package_dir, params):
         ignore = shutil.ignore_patterns(".svn", ".hg", ".hgignore", ".git", ".gitignore")
@@ -28,7 +23,7 @@ class BuildingPackageProvider(object):
         self._fetch_downloads(build_dir, build_env)
             
         build_script = os.path.join(build_dir, "whack/build")
-        os.mkdir(package_dir)
+        mkdir_p(package_dir)
         build_command = [
             "whack-run-with-whack-root",
             package_dir, # package_dir is mounted at WHACK_ROOT
@@ -47,21 +42,13 @@ class CachingPackageProvider(object):
         self._cacher = cacher
         self._underlying_provider = BuildingPackageProvider()
     
-    @contextlib.contextmanager
-    def provide_package(self, package_source, params):
-        install_id = _generate_install_id(package_source.path, params)
+    def provide_package(self, package_source, params, package_dir):
+        package_name = name_package(package_source, params)
+        result = self._cacher.fetch(package_name, package_dir)
         
-        with create_temporary_dir() as temp_dir:
-            cached_package_dir = os.path.join(temp_dir, "package")
-            
-            result = self._cacher.fetch(install_id, cached_package_dir)
-            
-            if result.cache_hit:
-                yield cached_package_dir
-            else:
-                with self._underlying_provider.provide_package(package_source, params) as package_dir:
-                    self._cacher.put(install_id, package_dir)
-                    yield package_dir
+        if not result.cache_hit:
+            self._underlying_provider.provide_package(package_source, params, package_dir)
+            self._cacher.put(package_name, package_dir)
 
 
 def params_to_build_env(params):
@@ -69,16 +56,3 @@ def params_to_build_env(params):
     for name, value in (params or {}).iteritems():
         build_env[name.upper()] = str(value)
     return build_env
-    
-
-def _generate_install_id(package_src_dir, params):
-    hasher = Hasher()
-    hasher.update(_uname("--kernel-name"))
-    hasher.update(_uname("--machine"))
-    hasher.update_with_dir(package_src_dir)
-    hasher.update(json.dumps(params, sort_keys=True))
-    return hasher.hexdigest()
-
-
-def _uname(arg):
-    return subprocess.check_output(["uname", arg])
